@@ -39,7 +39,7 @@ from __future__ import annotations
 
 # Standard Library
 import re
-from argparse import ArgumentDefaultsHelpFormatter, BooleanOptionalAction
+from argparse import ArgumentDefaultsHelpFormatter, BooleanOptionalAction, HelpFormatter
 from dataclasses import is_dataclass
 from pydoc import locate
 
@@ -56,14 +56,25 @@ TRE = re.compile(r"^.*?\[(.*)\]$")
 A = TypeVar("A")
 B = TypeVar("B")
 
-def from_dataclass(config: DC, ns: Union[dict[str, Any], None] = None) -> Config:
+try:
+    from rich_argparse import RichHelpFormatter as Formatter
+except ImportError:
+    Formatter = ArgumentDefaultsHelpFormatter  # type: ignore
+
+
+def from_dataclass(
+    config: DC,
+    *,
+    formatter: HelpFormatter = Formatter,  # type: ignore
+    ns: Union[dict[str, Any], None] = None,
+) -> Config:
     """Build config from dataclass."""
     if not is_dataclass(config):
         raise TypeError("config must be a dataclass.")
     return Config(
         Option(
             description=config.__doc__ or type(config).__name__,
-            formatter_class=ArgumentDefaultsHelpFormatter,
+            formatter_class=formatter,
         ),
         *_build_options(config, ns),
         dcls=config.__class__,
